"""

imfusion.machinelearning - Bindings for Machine Learning
==========================================================

This submodule provides Python bindings for the C++ ImFusion classes that can be used during the training of machine learning models.
"""
from __future__ import annotations
import abc as abc
import imfusion as imfusion
from imfusion._bindings import machinelearning as ml
from imfusion._bindings.machinelearning import AddCenterBoxOperation
from imfusion._bindings.machinelearning import AddDegradedLabelAsChannelOperation
from imfusion._bindings.machinelearning import AddPixelwisePredictionChannelOperation
from imfusion._bindings.machinelearning import AddPositionChannelOperation
from imfusion._bindings.machinelearning import AddRandomNoiseOperation
from imfusion._bindings.machinelearning import AdjustShiftScaleOperation
from imfusion._bindings.machinelearning import ApplyTopDownFlagOperation
from imfusion._bindings.machinelearning import ApproximateToHigherResolutionOperation
from imfusion._bindings.machinelearning import ArgMaxOperation
from imfusion._bindings.machinelearning import AxisFlipOperation
from imfusion._bindings.machinelearning import AxisRotationOperation
from imfusion._bindings.machinelearning import BakeDeformationOperation
from imfusion._bindings.machinelearning import BakePhotometricInterpretationOperation
from imfusion._bindings.machinelearning import BakeTransformationOperation
from imfusion._bindings.machinelearning import BlobsFromKeypointsOperation
from imfusion._bindings.machinelearning import BoundingBoxElement
from imfusion._bindings.machinelearning import BoundingBoxSet
from imfusion._bindings.machinelearning import Box
from imfusion._bindings.machinelearning import CenterROISampler
from imfusion._bindings.machinelearning import CheckDataOperation
from imfusion._bindings.machinelearning import ClipOperation
from imfusion._bindings.machinelearning import ComputingDevice
from imfusion._bindings.machinelearning import ConcatenateNeighboringFramesToChannelsOperation
from imfusion._bindings.machinelearning import ConvertSlicesToVolumeOperation
from imfusion._bindings.machinelearning import ConvertToGrayOperation
from imfusion._bindings.machinelearning import ConvertVolumeToSlicesOperation
from imfusion._bindings.machinelearning import ConvolutionalCRFOperation
from imfusion._bindings.machinelearning import CopyOperation
from imfusion._bindings.machinelearning import CropAroundLabelMapOperation
from imfusion._bindings.machinelearning import CropOperation
from imfusion._bindings.machinelearning import CutOutOperation
from imfusion._bindings.machinelearning import DataElement
from imfusion._bindings.machinelearning import DataElementException
from imfusion._bindings.machinelearning import DataItem
from imfusion._bindings.machinelearning import DataItemException
from imfusion._bindings.machinelearning import DataLoaderError
from imfusion._bindings.machinelearning import DataLoaderSpecs
from imfusion._bindings.machinelearning import Dataset
from imfusion._bindings.machinelearning import DefaultROISampler
from imfusion._bindings.machinelearning import DeformationOperation
from imfusion._bindings.machinelearning import DiceMetric
from imfusion._bindings.machinelearning import ElementType
from imfusion._bindings.machinelearning import Engine
from imfusion._bindings.machinelearning import EnsureExplicitMaskOperation
from imfusion._bindings.machinelearning import EnsureOneToOneMatrixMappingOperation
from imfusion._bindings.machinelearning import ExecutionProvider
from imfusion._bindings.machinelearning import ExtractRandomSubsetOperation
from imfusion._bindings.machinelearning import ExtractSubsetOperation
from imfusion._bindings.machinelearning import GammaCorrectionOperation
from imfusion._bindings.machinelearning import HighPassOperation
from imfusion._bindings.machinelearning import ImageElement
from imfusion._bindings.machinelearning import ImageMattingOperation
from imfusion._bindings.machinelearning import ImageROISampler
from imfusion._bindings.machinelearning import ImageSamplerError
from imfusion._bindings.machinelearning import ImagewiseClassificationMetrics
from imfusion._bindings.machinelearning import InterleaveMode
from imfusion._bindings.machinelearning import InvertOperation
from imfusion._bindings.machinelearning import KeepLargestComponentOperation
from imfusion._bindings.machinelearning import KeypointSet
from imfusion._bindings.machinelearning import KeypointsElement
from imfusion._bindings.machinelearning import KeypointsFromBlobsOperation
from imfusion._bindings.machinelearning import LabelROISampler
from imfusion._bindings.machinelearning import LabelTag
from imfusion._bindings.machinelearning import LinearIntensityMappingOperation
from imfusion._bindings.machinelearning import MRIBiasFieldCorrectionOperation
from imfusion._bindings.machinelearning import MRIBiasFieldGenerationOperation
from imfusion._bindings.machinelearning import MachineLearningModel
from imfusion._bindings.machinelearning import MakeFloatOperation
from imfusion._bindings.machinelearning import MarkAsLabelOperation
from imfusion._bindings.machinelearning import MarkAsTargetOperation
from imfusion._bindings.machinelearning import MergeAsChannelsOperation
from imfusion._bindings.machinelearning import Metric
from imfusion._bindings.machinelearning import MetricException
from imfusion._bindings.machinelearning import ModelType
from imfusion._bindings.machinelearning import MorphologicalFilterOperation
from imfusion._bindings.machinelearning import NormalizeMADOperation
from imfusion._bindings.machinelearning import NormalizeNormalOperation
from imfusion._bindings.machinelearning import NormalizePercentileOperation
from imfusion._bindings.machinelearning import NormalizeUniformOperation
from imfusion._bindings.machinelearning import OneHotOperation
from imfusion._bindings.machinelearning import Operation
from imfusion._bindings.machinelearning import OperationError
from imfusion._bindings.machinelearning import OperationsSequence
from imfusion._bindings.machinelearning import OrientedROISampler
from imfusion._bindings.machinelearning import ParamUnit
from imfusion._bindings.machinelearning import Phase
from imfusion._bindings.machinelearning import PixelwiseClassificationMetrics
from imfusion._bindings.machinelearning import PolyCropOperation
from imfusion._bindings.machinelearning import PredictionOutput
from imfusion._bindings.machinelearning import PredictionType
from imfusion._bindings.machinelearning import ProcessingRecordComponent
from imfusion._bindings.machinelearning import RandomAddDegradedLabelAsChannelOperation
from imfusion._bindings.machinelearning import RandomAxisFlipOperation
from imfusion._bindings.machinelearning import RandomAxisRotationOperation
from imfusion._bindings.machinelearning import RandomChoiceOperation
from imfusion._bindings.machinelearning import RandomCropAroundLabelMapOperation
from imfusion._bindings.machinelearning import RandomCropOperation
from imfusion._bindings.machinelearning import RandomCutOutOperation
from imfusion._bindings.machinelearning import RandomDeformationOperation
from imfusion._bindings.machinelearning import RandomGammaCorrectionOperation
from imfusion._bindings.machinelearning import RandomInvertOperation
from imfusion._bindings.machinelearning import RandomKeypointJitterOperation
from imfusion._bindings.machinelearning import RandomLinearIntensityMappingOperation
from imfusion._bindings.machinelearning import RandomMRIBiasFieldGenerationOperation
from imfusion._bindings.machinelearning import RandomPolyCropOperation
from imfusion._bindings.machinelearning import RandomROISampler
from imfusion._bindings.machinelearning import RandomResolutionReductionOperation
from imfusion._bindings.machinelearning import RandomRotationOperation
from imfusion._bindings.machinelearning import RandomScalingOperation
from imfusion._bindings.machinelearning import RandomSmoothOperation
from imfusion._bindings.machinelearning import RandomTemplateInpaintingOperation
from imfusion._bindings.machinelearning import RectifyRotationOperation
from imfusion._bindings.machinelearning import RemoveOperation
from imfusion._bindings.machinelearning import RenameOperation
from imfusion._bindings.machinelearning import ReplaceLabelsValuesOperation
from imfusion._bindings.machinelearning import ResampleDimsOperation
from imfusion._bindings.machinelearning import ResampleOperation
from imfusion._bindings.machinelearning import ResampleToInputOperation
from imfusion._bindings.machinelearning import ResetCriterion
from imfusion._bindings.machinelearning import ResolutionReductionOperation
from imfusion._bindings.machinelearning import RotationOperation
from imfusion._bindings.machinelearning import RunModelOperation
from imfusion._bindings.machinelearning import SISBasedElement
from imfusion._bindings.machinelearning import ScalingOperation
from imfusion._bindings.machinelearning import SelectChannelsOperation
from imfusion._bindings.machinelearning import SetLabelModalityOperation
from imfusion._bindings.machinelearning import SetMatrixToIdentityOperation
from imfusion._bindings.machinelearning import SetModalityOperation
from imfusion._bindings.machinelearning import SigmoidOperation
from imfusion._bindings.machinelearning import SmoothOperation
from imfusion._bindings.machinelearning import SoftmaxOperation
from imfusion._bindings.machinelearning import SplitROISampler
from imfusion._bindings.machinelearning import SurfaceDistancesMetric
from imfusion._bindings.machinelearning import SwapImageAndLabelsOperation
from imfusion._bindings.machinelearning import SyncOperation
from imfusion._bindings.machinelearning import TanhOperation
from imfusion._bindings.machinelearning import TargetTag
from imfusion._bindings.machinelearning import TemplateInpaintingOperation
from imfusion._bindings.machinelearning import ThresholdOperation
from imfusion._bindings.machinelearning import UnmarkAsTargetOperation
from imfusion._bindings.machinelearning import VectorElement
from imfusion._bindings.machinelearning import available_cpp_engines
from imfusion._bindings.machinelearning import available_engines
from imfusion._bindings.machinelearning import available_py_engines
from imfusion._bindings.machinelearning import is_label
from imfusion._bindings.machinelearning import is_semantic_segmentation_map
from imfusion._bindings.machinelearning import is_target
from imfusion._bindings.machinelearning import propertylist_to_data_loader_specs
from imfusion._bindings.machinelearning import register_filter_func
from imfusion._bindings.machinelearning import register_map_func
from imfusion._bindings.machinelearning import register_py_op_cls
from imfusion._bindings.machinelearning import tag_as_label
from imfusion._bindings.machinelearning import tag_as_target
from imfusion._bindings.machinelearning import untag_as_label
from imfusion._bindings.machinelearning import untag_as_target
from imfusion.machinelearning.torch_utils import to_torch
import platform as platform
import sys as sys
from . import engines
from . import torch_utils
__all__ = ['AbstractOperation', 'AddCenterBoxOperation', 'AddDegradedLabelAsChannelOperation', 'AddPixelwisePredictionChannelOperation', 'AddPositionChannelOperation', 'AddRandomNoiseOperation', 'AdjustShiftScaleOperation', 'ApplyTopDownFlagOperation', 'ApproximateToHigherResolutionOperation', 'ArgMaxOperation', 'AxisFlipOperation', 'AxisRotationOperation', 'BakeDeformationOperation', 'BakePhotometricInterpretationOperation', 'BakeTransformationOperation', 'BlobsFromKeypointsOperation', 'BoundingBoxElement', 'BoundingBoxSet', 'Box', 'CenterROISampler', 'CheckDataOperation', 'ClipOperation', 'ComputingDevice', 'ConcatenateNeighboringFramesToChannelsOperation', 'ConvertSlicesToVolumeOperation', 'ConvertToGrayOperation', 'ConvertVolumeToSlicesOperation', 'ConvolutionalCRFOperation', 'CopyOperation', 'CropAroundLabelMapOperation', 'CropOperation', 'CutOutOperation', 'DataElement', 'DataElementException', 'DataItem', 'DataItemException', 'DataLoaderError', 'DataLoaderSpecs', 'Dataset', 'DefaultROISampler', 'DeformationOperation', 'DiceMetric', 'ElementType', 'Engine', 'EnsureExplicitMaskOperation', 'EnsureOneToOneMatrixMappingOperation', 'ExecutionProvider', 'ExtractRandomSubsetOperation', 'ExtractSubsetOperation', 'GammaCorrectionOperation', 'HighPassOperation', 'ImageElement', 'ImageMattingOperation', 'ImageROISampler', 'ImageSamplerError', 'ImagewiseClassificationMetrics', 'InterleaveMode', 'InvertOperation', 'KeepLargestComponentOperation', 'KeypointSet', 'KeypointsElement', 'KeypointsFromBlobsOperation', 'LabelROISampler', 'LabelTag', 'LinearIntensityMappingOperation', 'MRIBiasFieldCorrectionOperation', 'MRIBiasFieldGenerationOperation', 'MachineLearningModel', 'MakeFloatOperation', 'MarkAsLabelOperation', 'MarkAsTargetOperation', 'MergeAsChannelsOperation', 'Metric', 'MetricException', 'ModelType', 'MorphologicalFilterOperation', 'NormalizeMADOperation', 'NormalizeNormalOperation', 'NormalizePercentileOperation', 'NormalizeUniformOperation', 'OneHotOperation', 'Operation', 'OperationError', 'OperationsSequence', 'OrientedROISampler', 'ParamUnit', 'Phase', 'PixelwiseClassificationMetrics', 'PolyCropOperation', 'PredictionOutput', 'PredictionType', 'ProcessingRecordComponent', 'RandomAddDegradedLabelAsChannelOperation', 'RandomAxisFlipOperation', 'RandomAxisRotationOperation', 'RandomChoiceOperation', 'RandomCropAroundLabelMapOperation', 'RandomCropOperation', 'RandomCutOutOperation', 'RandomDeformationOperation', 'RandomGammaCorrectionOperation', 'RandomInvertOperation', 'RandomKeypointJitterOperation', 'RandomLinearIntensityMappingOperation', 'RandomMRIBiasFieldGenerationOperation', 'RandomPolyCropOperation', 'RandomROISampler', 'RandomResolutionReductionOperation', 'RandomRotationOperation', 'RandomScalingOperation', 'RandomSmoothOperation', 'RandomTemplateInpaintingOperation', 'RectifyRotationOperation', 'RemoveOperation', 'RenameOperation', 'ReplaceLabelsValuesOperation', 'ResampleDimsOperation', 'ResampleOperation', 'ResampleToInputOperation', 'ResetCriterion', 'ResolutionReductionOperation', 'RotationOperation', 'RunModelOperation', 'SISBasedElement', 'ScalingOperation', 'SelectChannelsOperation', 'SetLabelModalityOperation', 'SetMatrixToIdentityOperation', 'SetModalityOperation', 'SigmoidOperation', 'SmoothOperation', 'SoftmaxOperation', 'SplitROISampler', 'SurfaceDistancesMetric', 'SwapImageAndLabelsOperation', 'SyncOperation', 'TanhOperation', 'TargetTag', 'TemplateInpaintingOperation', 'ThresholdOperation', 'UnmarkAsTargetOperation', 'VectorElement', 'abc', 'available_cpp_engines', 'available_engines', 'available_py_engines', 'engines', 'imfusion', 'is_label', 'is_semantic_segmentation_map', 'is_target', 'ml', 'platform', 'propertylist_to_data_loader_specs', 'register_filter_func', 'register_map_func', 'register_py_op_cls', 'sys', 'tag_as_label', 'tag_as_target', 'to_torch', 'torch_utils', 'untag_as_label', 'untag_as_target']
class AbstractOperation(imfusion._bindings.machinelearning.Operation):
    def __init__(self, name = '', processing_policy = ...):
        ...
    def __init_subclass__(self, *args, **kwargs):
        ...
def __DataElement_array(self: imfusion._bindings.machinelearning.DataElement, copy = False):
    ...
def __DataElement_iter(self) -> typing.Iterator:
    ...
